@@ -3,10 +3,12 @@
 ##############################################################
 ##   smscon-editor  -  Configuration UI for the SMSCON      ##
 ##############################################################
+# Copyright (c) 2010 Christos Zamantzas
+# Licenced under GPLv2
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-Version = '0.7-4'
+Version = '0.8-4'
 
 import os
 import sys
@@ -34,94 +36,94 @@ PassFile      = 'smsconEditorPass'             # name of password file
 ##############################################################
 
 def showMessage(message):
-    ''' Method to display a message to the user that waits for a confirmation. '''
+     ''' Method to display a message to the user that waits for a confirmation. '''
 
-    os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
+     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog \
                string:"%s" uint32:0 string:"OK"' % message)          
 
 ##############################################################  
 
 def showQuickMessage(message):
-    ''' Method to display a message to the user. '''
+     ''' Method to display a message to the user. '''
 
-    os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
+     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
                /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
 ##############################################################
 
 def CheckFile(Path, File):
-    ''' Check if a file exists. '''
+     ''' Check if a file exists. '''
 
-    try:
-        f = open(Path + File, 'r')
-        f.close()
-    except:
-        return False
-    else:
-        return True
+     try:
+         f = open(Path + File, 'r')
+         f.close()
+     except:
+         return False
+     else:
+         return True
 
 ##############################################################  
 
-def doCheckPassword(password):  ### FIXME: what should be the behaviour if password is missing?
-    ''' Check the given password. '''
+def doCheckPassword(password):  ### FIXME: what should be the behaviour if password is missing or empty?
+     ''' Check the given password. '''
     
-    if CheckFile(AppPath, PassFile) == True:
-       f = open(AppPath + PassFile, 'r')
-       Output = f.readlines() 
-       if Output == []:
-           message = 'Password is empty'
-           showQuickMessage(message)
-           f.close()
-           sys.exit(1)
-       else:
-          f.close()
-          if os.popen('echo "%s"|md5sum -c %s' % (password, AppPath + PassFile)).read() == '-: OK\n':
-            return True
-          else:
-            return False
-    else:
-       message = 'Password file does not exist!\nThe application will now exit..'
-       showQuickMessage(message)
-       #doUpdatePassword()
-       sys.exit(1)
+     if CheckFile(AppPath, PassFile) == True:
+         f = open(AppPath + PassFile, 'r')
+         Output = f.readlines() 
+         if Output == []:
+             message = 'Password is empty'
+             showQuickMessage(message)
+             f.close()
+             sys.exit(1)
+         else:
+             f.close()
+             if os.popen('echo "%s"|md5sum -c %s' % (password, AppPath + PassFile)).read() == '-: OK\n':
+                 return True
+             else:
+                 return False
+     else:
+         message = 'Password file does not exist!\nThe application will now exit..'
+         showQuickMessage(message)
+         #doUpdatePassword()
+         sys.exit(1)
 
 ##############################################################  
 
 def doCopyConfig():
-    '''Make a copy of the configuration for safe editing.'''  
+     '''Make a copy of the configuration for safe editing.'''  
 
-    #Check if configuration file exists.
-    if CheckFile(MainPath, ConfigFile) == True:
-       #Make the copy
-       os.system('cp %s %s' % (MainPath + ConfigFile, Path))
-    else:
-       message = 'Reading SMSCON settings gave a FATAL ERROR.\nThe configuration file does not exist or it is corrupted.'
-       showMessage(message)
-       if CheckFile(Path, ConfigFile) == True:
-          doUpdateConfig()
-          message = 'A settings file has been found in the user directory.\nIt will copied to the root directory and used as main.'
-          showMessage(message)
-       else:
-          os.system('sudo smscon -init')
-          message = 'SMSCON has been initialised to the default configuration.\
+     #Check if configuration file exists.
+     if CheckFile(MainPath, ConfigFile) == True:
+         #Make the copy
+         os.system('cp %s %s' % (MainPath + ConfigFile, Path))
+     else:
+         message = 'Reading SMSCON settings gave a FATAL ERROR.\nThe configuration file does not exist or it is corrupted.'
+         showMessage(message)
+         if CheckFile(Path, ConfigFile) == True:
+             doUpdateConfig()
+             message = 'A settings file has been found in the user directory.\nIt will copied to the root directory and used as main.'
+             showMessage(message)
+         else:
+             os.system('sudo smscon -init')
+             message = 'SMSCON has been initialised to the default configuration.\
                     \nThis editor will now quit...\n\nYou will need to open it again and edit your new configuration.'
-          showMessage(message)          
-          sys.exit(1)
+             showMessage(message)          
+             sys.exit(1)
 
 ##############################################################  
 
 def doUpdateConfig():
-    ''' Replace the config file with the edited and restart deamon. '''
-    Delay = 0.5
+     ''' Replace the config file with the edited and restart deamon. '''
+     Delay = 0.5
 
-    time.sleep(Delay)
-    os.system('sudo %ssmsconEditorCopyConfig'% AppPath)
-    time.sleep(Delay)
-    os.system('sudo smscon -stop')
-    time.sleep(Delay)
-    os.system('sudo smscon -start')
+     time.sleep(Delay)
+     os.system('sudo %ssmsconEditorCopyConfig'% AppPath)
+     time.sleep(Delay)
+     os.system('sudo smscon -stop')
+     time.sleep(Delay)
+     os.system('sudo smscon -start')
 
 ##############################################################  
 ##   
@@ -130,42 +132,49 @@ def doUpdateConfig():
 ##
 
 ConfigVars = ['SENDERNUMBER',                 
-               'EMAILADDRESS',
-               'COM_CHECK',
-               'COM_REBOOT',
-               'COM_POWEROFF',
-               'COM_POWER',
-               'COM_LOCATION',
-               'COM_REMOTEON',
-               'COM_REMOTEOFF',
-               'COM_CAMERA',
-               'COM_CALL',
-               'COM_LOCK', 
-               'COM_UNLOCK',
-               'COM_TRACKON',
-               'COM_TRACKOFF',
-               'COM_CUSTOM',
-               'COM_SHELL',
-               'USER',         
-               'PASSWORD',        
-               'EMAILFROM',       
-               'MAILSERVER',      
-               'MAILPORT',        
-               'REMOTEHOST',            
-               'REMOTEPORT',           
-               'REMOTEUSER',       
-               'REMOTEPASSWORD',
-               'DISABLESMS',
-               'COMMANDREPLY',
-               'AUTODEVICELOCK',
-               'AUTOBATREPORT',
-               'SIMUNLOCK',
-               'SILENCEDEVICE',
-               'KEYBOARDDETECT',
-               'GPSTIMEOUT',
-               'GPSPOLLING',
-               'GPSINTERVAL',
-               'GPSSEND']
+              'EMAILADDRESS',
+              'COM_CHECK',
+              'COM_REBOOT',
+              'COM_POWEROFF',
+              'COM_POWER',
+              'COM_LOCATION',
+              'COM_REMOTEON',
+              'COM_REMOTEOFF',
+              'COM_CAMERA',
+              'COM_CALL',
+              'COM_LOCK', 
+              'COM_UNLOCK',
+              'COM_TRACKON',
+              'COM_TRACKOFF',
+              'COM_CUSTOM',
+              'COM_SHELL',
+              'COM_ALARM',
+              'COM_RESTART',
+              'ENABLECHECKHOST',
+              'CHECKHOST',
+              'CHECKTIME',
+              'USER',         
+              'PASSWORD',        
+              'EMAILFROM',       
+              'MAILSERVER',      
+              'MAILPORT',
+              'REMOTEHOST',            
+              'REMOTEPORT',           
+              'REMOTEUSER',       
+              'REMOTEPASSWORD',
+              'MESSAGESEND',
+              'ENABLERESEND',
+              'RESENDTIME',
+              'COMMANDREPLY',
+              'KEYBOARDDETECT',
+              'AUTODEVICELOCK',
+              'SIMUNLOCK',
+              'AUTOBATREPORT',
+              'SILENCEDEVICE',
+              'GPSTIMEOUT',
+              'GPSPOLLING',
+              'GPSINTERVAL',
+              'GPSSEND']
 
 EncryptedConfigVars = ['USER',         
                        'PASSWORD',        
@@ -251,38 +260,38 @@ else:
 ##############################################################
 
 class MyStartupDialog(QtGui.QDialog): ### FIXME: add 3 re-tries for wrong password.
-       def __init__(self, parent=None):
-        
-          ##Build parent user interface
-          QtGui.QDialog.__init__(self, parent)
-          self.ui = Ui_DialogStart()
-          self.ui.setupUi(self)
-          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+     def __init__(self, parent=None):
 
-          ##Connect the button
-          QtCore.QObject.connect(self.ui.btnEnterPassword, QtCore.SIGNAL('clicked()'), self.doEnterPassword)
+         ##Build parent user interface
+         QtGui.QDialog.__init__(self, parent)
+         self.ui = Ui_DialogStart()
+         self.ui.setupUi(self)
+         ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+
+         ##Connect the button
+         QtCore.QObject.connect(self.ui.btnEnterPassword, QtCore.SIGNAL('clicked()'), self.doEnterPassword)
                
-       def doEnterPassword(self):
+     def doEnterPassword(self):
 
-          EnteredPassword = self.ui.linePassword.text()
-          if doCheckPassword(EnteredPassword) == True:
+         EnteredPassword = self.ui.linePassword.text()
+         if doCheckPassword(EnteredPassword) == True:
              message = 'Password Correct'
              showQuickMessage(message)
 
              self.close()
              return True
 
-          else:
+         else:
              message = 'Incorrect Password; Exiting..'
              showMessage(message)
              sys.exit(1)
 
-       ##Close app if window closes without a valid password
-       def closeEvent (self,event):
-          if self.doEnterPassword() == True:
+     ##Close app if window closes without a valid password
+     def closeEvent (self,event):
+         if self.doEnterPassword() == True:
              event.accept()
-          else:   
+         else:   
              message = 'You need to put a password; Exiting..'
              showMessage(message)
              sys.exit(1)
@@ -310,6 +319,7 @@ class MyMainWindow(QtGui.QMainWindow):
           QtCore.QObject.connect(self.ui.btnCreateConfigGeneral, QtCore.SIGNAL('clicked()'), self.doCreateConfigGeneral)
           QtCore.QObject.connect(self.ui.btnCreateConfigEmail, QtCore.SIGNAL('clicked()'), self.doCreateConfigEmail)
           QtCore.QObject.connect(self.ui.btnCreateConfigSSH, QtCore.SIGNAL('clicked()'), self.doCreateConfigSSH)
+          QtCore.QObject.connect(self.ui.btnCreateConfigHOST, QtCore.SIGNAL('clicked()'), self.doCreateConfigHOST)
           QtCore.QObject.connect(self.ui.btnCreateConfigCommands, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands)
             ##Initialise
           QtCore.QObject.connect(self.ui.btnInit, QtCore.SIGNAL('clicked()'), self.doInit)
@@ -342,7 +352,7 @@ class MyMainWindow(QtGui.QMainWindow):
           self.SetValues()
                
        def SetValues(self):
-          ''' Set values read in the GUI'''
+          ''' Set values read from the config in the GUI'''
           
           self.ui.linePhone.setText("%s" % SENDERNUMBER)
           self.ui.lineGPSTimeout.setText("%s" % GPSTIMEOUT)  
@@ -379,41 +389,74 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineSSHPassword.setText("%s" % REMOTEPASSWORD)
           self.ui.lineSSHHost.setText("%s" % REMOTEHOST)
           self.ui.lineSSHPort.setText("%s" % REMOTEPORT)
-            
+          
+          #set CHECKHOST fields:
+          self.ui.lineHostAddress.setText("%s" % CHECKHOST)
+          self.ui.lineHostInterval.setText("%s" % CHECKTIME)
+          if ENABLECHECKHOST == 'yes':
+             self.ui.checkBoxHostEnable.setChecked(True)
+             self.ui.lineHostAddress.setEnabled(True)
+             self.ui.lineHostInterval.setEnabled(True)
+          else:
+             self.ui.checkBoxHostEnable.setChecked(False)
+             self.ui.lineHostAddress.setEnabled(False)
+             self.ui.lineHostInterval.setEnabled(False)
+          
+          #set COMMANDREPLY fields:
+          self.ui.checkBoxCommandReply.setEnabled(True)
+          self.ui.checkBoxLowBattery.setEnabled(True)
+          self.ui.checkBoxKeyboardDetect.setEnabled(True)
+          if MESSAGESEND == 'sms':
+             self.ui.comboBoxReplyMethod.setCurrentIndex(0) 
+          elif MESSAGESEND == 'email':
+             self.ui.comboBoxReplyMethod.setCurrentIndex(1)
+          elif MESSAGESEND == 'both':
+             self.ui.comboBoxReplyMethod.setCurrentIndex(2)
+          elif MESSAGESEND == 'none':
+             self.ui.comboBoxReplyMethod.setCurrentIndex(3)
+             ##disable the following since not needed:
+             self.ui.checkBoxCommandReply.setEnabled(False)
+             self.ui.checkBoxLowBattery.setEnabled(False)
+             self.ui.checkBoxKeyboardDetect.setEnabled(False)
+
           if COMMANDREPLY == 'yes':
              self.ui.checkBoxCommandReply.setChecked(True)
           else:
              self.ui.checkBoxCommandReply.setChecked(False)
-          
-          if AUTODEVICELOCK == 'yes':
-             self.ui.checkBoxDeviceLock.setChecked(True)
-          else:
-             self.ui.checkBoxDeviceLock.setChecked(False)
-
-          if AUTOBATREPORT  == 'yes':
+          if AUTOBATREPORT == 'yes':
              self.ui.checkBoxLowBattery.setChecked(True)
           else:
              self.ui.checkBoxLowBattery.setChecked(False)
-             
-          if DISABLESMS     == 'yes':
-             self.ui.checkBoxNoSMS.setChecked(True)
-          else:
-             self.ui.checkBoxNoSMS.setChecked(False)
-             
-          if SIMUNLOCK  == 'yes':
-             self.ui.checkBoxNewSIMUnlock.setChecked(True)
-          else:
-             self.ui.checkBoxNewSIMUnlock.setChecked(False)
-             
-          if SILENCEDEVICE  == 'yes':
-             self.ui.checkBoxSilence.setChecked(True)
-          else:
-             self.ui.checkBoxSilence.setChecked(False)
-             
           if KEYBOARDDETECT == 'yes':
              self.ui.checkBoxKeyboardDetect.setChecked(True)
           else:
              self.ui.checkBoxKeyboardDetect.setChecked(False)  
+
+          if AUTODEVICELOCK == 'yes':
+             self.ui.checkBoxDeviceLock.setChecked(True)
+          else:
+             self.ui.checkBoxDeviceLock.setChecked(False)
+            
+          if SIMUNLOCK == 'yes':
+             self.ui.checkBoxNewSIMUnlock.setChecked(True)
+          else:
+             self.ui.checkBoxNewSIMUnlock.setChecked(False)
+             
+          if SILENCEDEVICE == 'yes':
+             self.ui.checkBoxSilence.setChecked(True)
+          else:
+             self.ui.checkBoxSilence.setChecked(False)
+             
+          if ENABLERESEND == 'yes':
+             self.ui.checkBoxEnableRetry.setChecked(True)
+          else:
+             self.ui.checkBoxEnableRetry.setChecked(False)
+             ##disable the following since not needed:
+             self.ui.lineReplyWait.setEnabled(False)
+             #self.ui.lineRetryAttempts.setEnabled(False)
+
+          self.ui.lineReplyWait.setText("%s" % RESENDTIME)
+          #self.ui.lineRetryAttempts.setText("%s" % MAXRESEND)
           
           self.ui.lineCheck.setText(    "%s" % COM_CHECK)
           self.ui.lineReboot.setText(   "%s" % COM_REBOOT)
@@ -430,14 +473,16 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineTrackOff.setText( "%s" % COM_TRACKOFF)
           self.ui.lineScript.setText(   "%s" % COM_CUSTOM)
           self.ui.lineShell.setText(    "%s" % COM_SHELL)
+          self.ui.lineAlarm.setText(    "%s" % COM_ALARM)
+          self.ui.lineRestart.setText(  "%s" % COM_RESTART)
        
        def doAbout(self):
           self.aboutWin = SMSCONAbout(self)
 
        def doCredits(self):
-          msg = unichr(int('00A9', 16)) + "SMSCON - 2010, Frank Visser (digitalvoid)\n"
+          msg = unichr(int('00A9', 16)) + "SMSCON - 2010/2011, Frank Visser (digitalvoid)\n"
           msg += "Control and Track your N900 through SMS\n\n"
-          msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010, Christos Zamantzas (saturn)\n"
+          msg += unichr(int('00A9', 16)) + "SMSCON Editor - 2010/2011, Christos Zamantzas (saturn)\n"
           msg += "Configuration and Test user interface for the SMSCON daemon\n\n"
           msg += "Distributed under GPL ver. 2"
           QMessageBox.about(self, "Credits - SMSCON & SMSCON Editor", msg)
@@ -484,12 +529,21 @@ class MyMainWindow(QtGui.QMainWindow):
 
        ##TAB: General    
        def doCreateConfigGeneral(self):
-          DefaultPhone = self.ui.linePhone.text()
-          GPSTimeout   = self.ui.lineGPSTimeout.text()
-          GPSPolling   = self.ui.lineGPSPolling.text()
-          GPSInterval  = self.ui.comboBoxGPSInterval.currentText()
-          GPSSend      = self.ui.comboBoxGPSSend.currentText()
-        
+          DefaultPhone   = self.ui.linePhone.text()
+          GPSTimeout     = self.ui.lineGPSTimeout.text()
+          GPSPolling     = self.ui.lineGPSPolling.text()
+          GPSInterval    = self.ui.comboBoxGPSInterval.currentText()
+          GPSSend        = self.ui.comboBoxGPSSend.currentText()
+          ReplySend      = self.ui.comboBoxReplyMethod.currentText()
+          ReplyWait      = self.ui.lineReplyWait.text()
+          #ReplyAttempts  = self.ui.lineRetryAttempts.text()
+
+          EnableReply = self.ui.checkBoxEnableRetry.isChecked()
+          if EnableReply is True:
+             EnableReply = "yes"
+          else:
+             EnableReply = "no"          
+
           CommandReply = self.ui.checkBoxCommandReply.isChecked()
           if CommandReply is True:
              CommandReply = "yes"
@@ -508,12 +562,6 @@ class MyMainWindow(QtGui.QMainWindow):
           else:
              LowBattery = "no"
              
-          NoSMS = self.ui.checkBoxNoSMS.isChecked()
-          if NoSMS is True:
-             NoSMS = "yes"
-          else:
-             NoSMS = "no"
-
           NewSIMUnlock = self.ui.checkBoxNewSIMUnlock.isChecked()
           if NewSIMUnlock is True:
              NewSIMUnlock = "yes"
@@ -551,8 +599,14 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('AUTODEVICELOCK    = \'%s\'\n' % AutoDeviceLock)
              elif Line.startswith("AUTOBATREPORT"):
                 destination.write('AUTOBATREPORT     = \'%s\'\n' % LowBattery)
-             elif Line.startswith("DISABLESMS"):
-                destination.write('DISABLESMS        = \'%s\'\n' % NoSMS)
+             elif Line.startswith("MESSAGESEND "):
+                destination.write('MESSAGESEND       = \'%s\'\n' % ReplySend)
+             elif Line.startswith("ENABLERESEND "):
+                destination.write('ENABLERESEND      = \'%s\'\n' % EnableReply)
+             elif Line.startswith("RESENDTIME "):
+                destination.write('RESENDTIME        = \'%s\'\n' % ReplyWait)
+             #elif Line.startswith("MAXRESEND "):
+             #   destination.write('MAXRESEND         = \'%s\'\n' % ReplyAttempts)
              elif Line.startswith("SIMUNLOCK"):
                 destination.write('SIMUNLOCK         = \'%s\'\n' % NewSIMUnlock)
              elif Line.startswith("SILENCEDEVICE"):
@@ -646,6 +700,8 @@ class MyMainWindow(QtGui.QMainWindow):
           self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
           self.ui.lineScript.setText(   "%s" % prefix + COM_CUSTOM)
           self.ui.lineShell.setText(    "%s" % prefix + COM_SHELL)
+          self.ui.lineAlarm.setText(    "%s" % prefix + COM_ALARM)
+          self.ui.lineRestart.setText(  "%s" % prefix + COM_RESTART)
           
        def doCreateConfigCommands(self):
 
@@ -664,6 +720,8 @@ class MyMainWindow(QtGui.QMainWindow):
           PowerOff  = self.ui.linePowerOff.text()
           Script    = self.ui.lineScript.text()
           Shell     = self.ui.lineShell.text()
+          Alarm     = self.ui.lineAlarm.text()
+          Restart   = self.ui.lineRestart.text()
           
           #Update of the config file.
           os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
@@ -700,6 +758,10 @@ class MyMainWindow(QtGui.QMainWindow):
                 destination.write('COM_CUSTOM        = \'%s\'\n' % Script)
              elif Line.startswith("COM_SHELL"):
                 destination.write('COM_SHELL         = \'%s\'\n' % Shell)                   
+             elif Line.startswith("COM_ALARM"):
+                destination.write('COM_ALARM         = \'%s\'\n' % Alarm)                   
+             elif Line.startswith("COM_RESTART"):
+                destination.write('COM_RESTART       = \'%s\'\n' % Restart)
              else: 
                 destination.write( Line )
           source.close()
@@ -714,10 +776,14 @@ class MyMainWindow(QtGui.QMainWindow):
           
        ##TAB: SSH Settings
        def doCreateConfigSSH(self):
-          SSHUsername = self.ui.lineSSHUsername.text()
-          SSHPassword = self.ui.lineSSHPassword.text()
-          SSHHost     = self.ui.lineSSHHost.text()
-          SSHPort     = self.ui.lineSSHPort.text()
+
+          message = 'Updating. Please wait..'
+          showQuickMessage(message)
+
+          SSHUsername  = self.ui.lineSSHUsername.text()
+          SSHPassword  = self.ui.lineSSHPassword.text()
+          SSHHost      = self.ui.lineSSHHost.text()
+          SSHPort      = self.ui.lineSSHPort.text()
 
          # Update of the config file.
           os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
@@ -737,17 +803,53 @@ class MyMainWindow(QtGui.QMainWindow):
           source.close()
           destination.close()
 
-          message = 'Updating. Please wait..'
-          showQuickMessage(message)
           doUpdateConfig()
           
-          message = 'The SSH Settings have been successfully saved.\
+          message = 'The Reverse SSH settings have been successfully saved in the configuration.\
                      \nUser name: %s\nPassword: %s\nHost: %s - Port: %s' % (SSHUsername,
                                                                             SSHPassword,
                                                                             SSHHost,
                                                                             SSHPort)
           showMessage(message)
 
+       def doCreateConfigHOST(self):
+
+          message = 'Updating. Please wait..'
+          showQuickMessage(message)
+       
+          HostAddress  = self.ui.lineHostAddress.text()
+          HostInterval = self.ui.lineHostInterval.text()
+          HostEnable   = self.ui.checkBoxHostEnable.isChecked()
+          if HostEnable is True:
+             HostEnable = "yes"
+          else:
+             HostEnable = "no"          
+
+         # Update of the config file.
+          os.rename( Path + ConfigFile, Path + ConfigFile + "~" )
+          destination = open( Path + ConfigFile, "w" )
+          source = open( Path + ConfigFile + "~", "r" )
+          for Line in source:
+             if   Line.startswith("CHECKHOST"):
+                destination.write('CHECKHOST         = \'%s\'\n' % HostAddress)
+             elif Line.startswith("CHECKTIME"):
+                destination.write('CHECKTIME         = %s \n' % HostInterval)
+             elif Line.startswith("ENABLECHECKHOST"):
+                destination.write('ENABLECHECKHOST   = \'%s\'\n' % HostEnable)
+             else: 
+                destination.write( Line )
+          source.close()
+          destination.close()
+
+          doUpdateConfig()
+          
+          message = 'The Remote Host settings have been successfully saved in the configuration.\
+                     \nEnabled: %s\nHost Address: %s\nCheck Interval: %s' % (HostEnable,
+                                                                            HostAddress,
+                                                                            HostInterval)
+          showMessage(message)
+
+             
        ##TAB: TESTING
        def doSendTestMail1(self):
           os.system('sudo smscon -test email1')
@@ -798,42 +900,42 @@ class MyMainWindow(QtGui.QMainWindow):
        
 class MyPasswordDialog(QtGui.QDialog):
 
-       def __init__(self, parent=None):
-          ##Build the parent user interface
-          QtGui.QDialog.__init__(self, parent)
-          self.ui = Ui_DialogPassword()
-          self.ui.setupUi(self)
-          ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-          self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+     def __init__(self, parent=None):
+         ##Build the parent user interface
+         QtGui.QDialog.__init__(self, parent)
+         self.ui = Ui_DialogPassword()
+         self.ui.setupUi(self)
+         ##self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
           
-          ##Connect the button
-          QtCore.QObject.connect(self.ui.btnNewPassword, QtCore.SIGNAL('clicked()'), self.doNewPassword)
+         ##Connect the button
+         QtCore.QObject.connect(self.ui.btnNewPassword, QtCore.SIGNAL('clicked()'), self.doNewPassword)
              
-       def doNewPassword(self):
+     def doNewPassword(self):
 
-          NewPassword1 = self.ui.lineNewPassword1.text()
-          NewPassword2 = self.ui.lineNewPassword2.text()
+         NewPassword1 = self.ui.lineNewPassword1.text()
+         NewPassword2 = self.ui.lineNewPassword2.text()
           
-          if   NewPassword1 != NewPassword2:
+         if   NewPassword1 != NewPassword2:
              message = 'The two cases are not equal. No change has been made.'
              showMessage(message)
              self.close()
-          elif NewPassword1 == NewPassword2:
+         elif NewPassword1 == NewPassword2:
              NewPassword = NewPassword1
              if NewPassword == '':
-               NewPassword = '12345'
-          try:
+                 NewPassword = '12345'
+         try:
              try:
-               os.remove( AppPath + PassFile )
+                 os.remove( AppPath + PassFile )
              except:
-               pass 
+                 pass 
              time.sleep(1)             
              os.system('sudo %ssmsconEditorCreatePass %s %s' % (AppPath, NewPassword, AppPath + PassFile))
-          except:
+         except:
              message = 'The new password hash could not be stored.'
              showMessage(message)
              self.close()
-          else: 
+         else: 
              message = 'The new password hash has been computed and stored.'
              showMessage(message)
              self.close()
@@ -841,122 +943,117 @@ class MyPasswordDialog(QtGui.QDialog):
 ##############################################################
 
 class SMSCONAbout(QtGui.QMainWindow):
-    '''About Window'''
-    def __init__(self, parent=None):
-        QMainWindow.__init__(self,parent)
-        self.parent = parent
-        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-        self.setWindowTitle("SMSCON Editor About")
+     '''About Window'''
+     def __init__(self, parent=None):
+         QMainWindow.__init__(self,parent)
+         self.parent = parent
+         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+         self.setWindowTitle("SMSCON Editor About")
 
-        aboutScrollArea = QScrollArea(self)
-        aboutScrollArea.setWidgetResizable(True)
-        awidget = QWidget(aboutScrollArea)
-        awidget.setMinimumSize(470,1100)
-        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
-        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
-        #Kinetic scroller is available on Maemo and should be on meego
-        try:
-            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
-            scroller.setEnabled(True)
-        except:
-            pass
+         aboutScrollArea = QScrollArea(self)
+         aboutScrollArea.setWidgetResizable(True)
+         awidget = QWidget(aboutScrollArea)
+         awidget.setMinimumSize(470,1100)
+         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+         #Kinetic scroller is available on Maemo and should be on meego
+         try:
+             scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+             scroller.setEnabled(True)
+         except:
+             pass
 
-        aboutLayout = QVBoxLayout(awidget)
+         aboutLayout = QVBoxLayout(awidget)
 
-        aboutIcon = QLabel()
-        aboutIcon.setPixmap( QIcon.fromTheme('smscon-editor').pixmap(48,48) )
-        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
-        aboutIcon.resize(128,128)
-        aboutLayout.addWidget(aboutIcon)
+         aboutIcon = QLabel()
+         aboutIcon.setPixmap( QIcon.fromTheme('smscon-editor').pixmap(48,48) )
+         aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+         aboutIcon.resize(128,128)
+         aboutLayout.addWidget(aboutIcon)
 
-        aboutLabel = QLabel('''<center><b>SMSCON Editor</b> 
-                                   <br>version: %s
-                                   <br>
-                                   <br>
-                                   <b>The SMSCON Editor is a user interface 
-                                   <br>to the configuration of the SMSCON.</b>
-                                   <br>
-                                   <br>Licenced under GPLv2
-                                   <br>by <b>Christos Zamantzas</b> (Saturn)
-                                   <br>
-                                   <br>It provides the ability to edit 
-                                   <br>the options and name the secret  
-                                   <br>pass-phrases of the commands used 
-                                   <br>for controlling the device.
-                                   <br>
-                                   <br>In addition, it provides an interface 
-                                   <br>to initialise and configure the 
-                                   <br>SMSCON daemon.
-                                   <br>
-                                   <br>Additional information on the usage, 
-                                   <br>settings and implications can be found in
-                                   <br>the wiki pages (see buttons at the end).
-                                   <br>
-                                   <br>
-                                   <br><b>Thanks to:</b>
-                                   <br><b>Frank Visser</b> (Digitalvoid) for 
-                                   <br>the code to import, decrypt and encrypt 
-                                   <br>the user variables at the config file.
-                                   <br>
-                                   <br><b>Benoit HERVIER</b> at http://khertan.net/
-                                   <br>for the code used in this about window.
-                                   <br>
-                                   </center>''' % Version)
-        aboutLayout.addWidget(aboutLabel)
-        self.wiki1_button = QPushButton('SMSCON')
-        self.wiki1_button.clicked.connect(self.open_wiki1)
-        self.wiki2_button = QPushButton('SMSCON Editor')
-        self.wiki2_button.clicked.connect(self.open_wiki2)
-        awidget2 = QWidget()
-        buttonLayout = QHBoxLayout(awidget2)        
-        buttonLayout.addWidget(self.wiki1_button)
-        buttonLayout.addWidget(self.wiki2_button)
-        aboutLayout.addWidget(awidget2)
+         aboutLabel = QLabel('''<center><b>SMSCON Editor</b> 
+                               <br>version: %s
+                               <br>
+                               <br>
+                               <b>The SMSCON Editor is a user interface 
+                               <br>to the configuration of the SMSCON.</b>
+                               <br>
+                               <br>Licenced under GPLv2
+                               <br>by <b>Christos Zamantzas</b> (Saturn)
+                               <br>
+                               <br>It provides the ability to edit 
+                               <br>the options and name the secret  
+                               <br>pass-phrases of the commands used 
+                               <br>for controlling the device.
+                               <br>
+                               <br>In addition, it provides an interface 
+                               <br>to initialise and configure the 
+                               <br>SMSCON daemon.
+                               <br>
+                               <br>Additional information on the usage, 
+                               <br>settings and implications can be found in
+                               <br>the wiki pages (see buttons at the end).
+                               <br>
+                               <br>
+                               <br><b>Thanks to:</b>
+                               <br><b>Frank Visser</b> (Digitalvoid) for 
+                               <br>the code to import, decrypt and encrypt 
+                               <br>the user variables at the config file.
+                               <br>
+                               <br><b>Benoit HERVIER</b> at http://khertan.net/
+                               <br>for the code used in this about window.
+                               <br>
+                               </center>''' % Version)
+         aboutLayout.addWidget(aboutLabel)
+         self.wiki1_button = QPushButton('SMSCON')
+         self.wiki1_button.clicked.connect(self.open_wiki1)
+         self.wiki2_button = QPushButton('SMSCON Editor')
+         self.wiki2_button.clicked.connect(self.open_wiki2)
+         awidget2 = QWidget()
+         buttonLayout = QHBoxLayout(awidget2)        
+         buttonLayout.addWidget(self.wiki1_button)
+         buttonLayout.addWidget(self.wiki2_button)
+         aboutLayout.addWidget(awidget2)
         
-        awidget.setLayout(aboutLayout)
-        aboutScrollArea.setWidget(awidget)
-        self.setCentralWidget(aboutScrollArea)
-        self.show()        
+         awidget.setLayout(aboutLayout)
+         aboutScrollArea.setWidget(awidget)
+         self.setCentralWidget(aboutScrollArea)
+         self.show()        
         
-    def open_wiki1(self):
-        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON'))
-    def open_wiki2(self):
-        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON_Editor'))
-
+     def open_wiki1(self):
+         QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON'))
+     def open_wiki2(self):
+         QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/SMSCON_Editor'))
 
 ##############################################################        
-             
+
 class smsconEditorMain():
         
-          ##############################################################  
+     ##Check with what priviledges the GUI has been executed.
+     if os.geteuid() == 0:
+         message ='ERROR: SMSCON Editor should not be executed as root. Exiting..'
+         showMessage(message)
+         sys.exit(1)
 
-          ##Check with what priviledges the GUI has been executed.
-          if os.geteuid() == 0:
-             message ='ERROR: SMSCON Editor should not be executed as root. Exiting..'
-             showMessage(message)
-             sys.exit(1)
+     ##Check if temp folder is available   
+     if os.path.exists(Path) == False:
+         os.system('mkdir %s' % Path)
+         message ='First Time Use: Creating temp folders..'
+         showQuickMessage(message)
+     else:
+         pass
+     ##Check if temp config file available
+     if CheckFile(Path, ConfigFile) == False:
+         message ='First Time Use: Creating temp folders..'
+         showQuickMessage(message)
+         doCopyConfig()
+     else:
+         pass
 
-          ##Check if temp folder is available   
-          if os.path.exists(Path) == False:
-             os.system('mkdir %s' % Path)
-             message ='First Time Use: Creating temp folders..'
-             showQuickMessage(message)
-          else:
-             pass
-          ##Check if temp config file available
-          if CheckFile(Path, ConfigFile) == False:
-             message ='First Time Use: Creating temp folders..'
-             showQuickMessage(message)
-             doCopyConfig()
-          else:
-             pass
-            
-          ##############################################################         
-          app = QtGui.QApplication(sys.argv)
-          #Open Main Window
-          myapp = MyMainWindow()
-          myapp.show()
+     app = QtGui.QApplication(sys.argv)
+     #Open Main Window
+     myapp = MyMainWindow()
+     myapp.show()
 
-          sys.exit(app.exec_())
-          
\ No newline at end of file
+     sys.exit(app.exec_())
